Aggregator.App.index\_query.IndexAggregator
===========================================

.. currentmodule:: Aggregator.App.index_query

.. autoclass:: IndexAggregator

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~IndexAggregator.__init__
      ~IndexAggregator.aclose
      ~IndexAggregator.aopen
      ~IndexAggregator.get_all_CC_indexes
      ~IndexAggregator.get_captured_responses
      ~IndexAggregator.get_number_of_pages
   
   

   
   
   